Stan Math Library: stan/math/prim/mat/fun/exp.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
exp.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <boost/math/special_functions/fpclassify.hpp>`
`#include <limits>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , int Rows, int Cols>
Eigen::Matrix< T, Rows, Cols > | stan::math::exp (const Eigen::Matrix< T, Rows, Cols > &m)
| Return the element-wise exponentiation of the matrix or vector. More...
template<int Rows, int Cols>
Eigen::Matrix< double, Rows, Cols > | stan::math::exp (const Eigen::Matrix< double, Rows, Cols > &m)

[ Stan Home Page ] © 2011–2016, Stan Development Team.